#
# spec file for package python-annoy
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python36 1
Name:           python-annoy
Version:        1.17.3
Release:        1.6
Summary:        Approximation of Nearest Neighbors
License:        Apache-2.0
URL:            https://github.com/spotify/annoy
Source:         https://github.com/spotify/annoy/archive/v%{version}.tar.gz
# PATCH-FIX-OPENSUSE boo#1100677
Patch0:         reproducible.patch
BuildRequires:  %{python_module cached-property}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module h5py}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
Annoy (Approximate Nearest Neighbors) is a C++ library with Python
bindings to search for points in space that are close to a given
query point. It also creates large read-only file-based data
structures that are mmapped into memory so that many processes may
share the same data.

%prep
%autosetup -p1 -n annoy-%{version}
# fix testdata location
sed -i -e "s:'test/test:'test:g" test/index_test.py

%build
sed -i '/setup_requires/d' setup.py
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# online tests: test_fashion_mnist, test_glove_25, test_nytimes_16
# fails on 32bit: test_distance_consistency
# fails on 32bit: test_very_large_index
%pytest_arch -k 'not (test_fashion_mnist or test_glove_25 or test_nytimes_16 or test_distance_consistency or test_very_large_index)'

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitearch}/annoy
%{python_sitearch}/annoy*-info

%changelog
* Mon Oct 30 2023 pgajdos@suse.com
- update to version 1.17.3
  update to 1.17.3:
  * Essentially just #645 which fixes compilation on OS X
  update to 1.17.2:
  * Fixed memory leak reported in #633
- drop unneeded denose.patch (they switched to pytest)
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to v1.17.1:
  * Add -fpermissive plus some other minor things
* Mon Apr 19 2021 Steve Kowalik <steven.kowalik@suse.com>
- Don't build on Python 3.6 due to no NumPy.
* Wed Jan 20 2021 Markéta Machová <mmachova@suse.com>
- Update to 1.17.0
  * multithreaded building + misc more
- Add denose.patch to get rid of nose
* Wed Jan 20 2021 John Vandenberg <jayvdb@gmail.com>
- Skip one test flaky on Python 3.6
* Mon Mar  2 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip one more test failing on 32bit
* Thu Jan 16 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.16.3
  * some error message improvements
  * doing more stack allocations instead of heap
  * fixes to a few tests that were failing on other platforms
- Rebase patch reproducible.patch
* Wed Sep 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip test test_distance_consistency that fails on 32bit
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.16.0:
  * Various warning fixes
  * Cleanups
- Rebase patch reproducible.patch
* Tue May 14 2019 svasudevan@suse.com
- Update to 1.15.2
  * Fix #379 error handling in save()
  * Fix compile issue in linux
  * Fix popcount #366
  * rebased reproduceable.patch
  * Some more misc
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.15.1:
  * Various minor fixes
  * Fixes to the Euclidean distance function (avoid catastrophic cancellation)
  * Don't MAP_POPULATE by default
  * dot products are now supported
- Update patch reproducible.patch:
  * expand to not screw with cflags either
* Tue Jul 10 2018 bwiedemann@suse.com
- Add reproducible.patch to not depend on build system CPU (boo#1100677)
* Wed May  9 2018 toddrme2178@gmail.com
- Update to 1.12.0
  * Finally squashed a remaining issue with holes (see #295) and
    together with a few other holes-related fixes it felt worthy of
    bumping the minor version number.
  * Fix more holes issues (this time causing the number of items to
    be reported incorrectly)
  * Fix angular index with holes
  * This version features AVX instructions thanks to @ReneHollander
  * Windows support now official – with CI pipeline to prove it.
    Only tested on Python 3.6 so far
  * Experimental Hamming distances
- Use license tag
* Tue Nov  7 2017 toddrme2178@gmail.com
- initial version
